==================================================
Workspaces or Usecases setup using the File Server
==================================================

The following workspaces have been setup using the Epiviz File Server


1. `BICCN/NEMO Miniatlas Mouse MOp Dataset <https://github.com/epiviz/miniatlas>`_
2. `BICCN Cross Species Dataset <https://github.com/epiviz/biccn_cross_species>`_